@@ -3,9 +3,9 @@ extern crate lazy_static;
 extern crate pathfinding;
 extern crate rand;
 
-use pathfinding::prelude::{astar, idastar};
-use rand::os::OsRng;
+use pathfinding::prelude::{absdiff, astar, idastar};
 use rand::Rng;
+use rand::os::OsRng;
 use std::time::Instant;
 
 #[cfg(test)]
@@ -14,16 +14,12 @@ const SIDE: u8 = 3;
 const SIDE: u8 = 4;
 const LIMIT: usize = (SIDE * SIDE) as usize;
 
-macro_rules! absdiff {
-    ($a:expr, $b:expr) => { if $a > $b { $a - $b } else { $b - $a } }
-}
-
 #[cfg_attr(feature = "cargo-clippy", allow(derive_hash_xor_eq))]
 #[derive(Clone, Debug, Hash)]
 struct Game {
     positions: [u8; LIMIT], // Correct position of piece at every index
     hole_idx: u8,           // Current index of the hole
-    weight: u8,             // Current some of pieces manhattan distances
+    weight: u8,             // Current some of pieces Manhattan distances
 }
 
 impl PartialEq for Game {
@@ -47,16 +43,17 @@ lazy_static! {
         hole_idx: 0,
         weight: 0,
     };
-
-    static ref NEIGHBOURS: Vec<Vec<u8>> = (0..SIDE*SIDE).map(|idx|
-        (0..4).filter_map(|dir|
-                          match dir {
-                              0 if idx % SIDE > 0 => Some(idx - 1),
-                              1 if idx >= SIDE => Some(idx - SIDE),
-                              2 if idx % SIDE < SIDE - 1 => Some(idx + 1),
-                              3 if idx < SIDE * SIDE - SIDE => Some(idx + SIDE),
-                              _ => None,
-                          }).collect::<Vec<_>>()).collect();
+    static ref NEIGHBOURS: Vec<Vec<u8>> = (0..SIDE * SIDE)
+        .map(|idx| (0..4)
+            .filter_map(|dir| match dir {
+                0 if idx % SIDE > 0 => Some(idx - 1),
+                1 if idx >= SIDE => Some(idx - SIDE),
+                2 if idx % SIDE < SIDE - 1 => Some(idx + 1),
+                3 if idx < SIDE * SIDE - SIDE => Some(idx + SIDE),
+                _ => None,
+            })
+            .collect::<Vec<_>>())
+        .collect();
 }
 
 impl Game {
@@ -81,14 +78,14 @@ impl Game {
         pos / SIDE
     }
 
-    // Compute the manhattan distance between the piece at idx and its correct position.
+    // Compute the Manhattan distance between the piece at idx and its correct position.
     fn distance(&self, idx: u8) -> u8 {
         let (actual_x, actual_y) = (Self::x(idx), Self::y(idx));
         let (correct_x, correct_y) = (
             Self::x(self.positions[idx as usize]),
             Self::y(self.positions[idx as usize]),
         );
-        absdiff!(actual_x, correct_x) + absdiff!(actual_y, correct_y)
+        absdiff(actual_x, correct_x) + absdiff(actual_y, correct_y)
     }
 
     fn solved(&self) -> bool {
